@@ -11,11 +11,12 @@
 #     HomePage: http://www.vimer.cn
 #
 #      Created: 2012-11-28 15:11:48
-#      Version: 0.0.3
 #      History:
 #               0.0.1 | dantezhu | 2012-11-28 15:11:48 | init
 #               0.0.2 | dantezhu | 2012-11-28 21:13:39 | no cache
 #               0.0.3 | dantezhu | 2012-11-29 23:36:24 | url encode
+#               0.0.4 | dantezhu | 2012-11-30 11:00:46 | content-type
+#               0.0.5 | dantezhu | 2013-07-16 12:06:59 | 使用encodeURIComponent，否则中文有问题
 #
 #=============================================================================
 """
@@ -35,31 +36,6 @@ UTIL_JS_TPL = """
 
 var django_util = function(){
 
-    function url_encode(clearString) {
-        var output = '';
-        var x = 0;
-        clearString = clearString.toString();
-        var regex = /(^[a-zA-Z0-9-_.]*)/;
-        while (x < clearString.length) {
-            var match = regex.exec(clearString.substr(x));
-            if (match != null && match.length > 1 && match[1] != '') {
-                output += match[1];
-                x += match[1].length;
-            } else {
-                if (clearString.substr(x, 1) == ' ') {
-                    output += '+';
-                }
-                else {
-                    var charCode = clearString.charCodeAt(x);
-                    var hexVal = charCode.toString(16);
-                    output += '%' + ( hexVal.length < 2 ? '0' : '' ) + hexVal.toUpperCase();
-                }
-                x++;
-            }
-        }
-        return output;
-    }
-
     function _get_path(name, kwargs, urls)
     {
 
@@ -80,7 +56,7 @@ var django_util = function(){
                 {
                     throw(key + ' does not exist in ' + _path);
                 }
-                path = path.replace('<' + key +'>', url_encode(kwargs[key]));
+                path = path.replace('<' + key +'>', encodeURIComponent(kwargs[key]));
             }
         }
 
@@ -173,6 +149,9 @@ def django_util_js(request):
     
     content = t.render(c)
 
-    response = HttpResponse(content, mimetype='text/javascript')
+    response = HttpResponse(
+        content, 
+        content_type='text/javascript; charset=UTF-8',
+        )
     response['Cache-Control'] = 'no-cache'
     return response
